BasicMarkdown class
Constructors
-
BasicMarkdown({Key? key, required String data, MarkdownStyleSheet? styleSheet, SyntaxHighlighter? syntaxHighlighter, MarkdownTapLinkCallback? onTapLink, int? maxLines})
-
Non-scrolling Markdown renderer.
const
Properties
-
blockSyntaxes
→ List<BlockSyntax>?
-
Collection of custom block syntax types to be used parsing the Markdown data.
finalinherited
-
builders
→ Map<String, MarkdownElementBuilder>
-
Render certain tags, usually used with
extensionSet
finalinherited
-
bulletBuilder
→ MarkdownBulletBuilder?
-
Called when building a bullet
finalinherited
-
checkboxBuilder
→ MarkdownCheckboxBuilder?
-
Call when build a checkbox widget.
finalinherited
-
data
→ String
-
The Markdown to display.
finalinherited
-
extensionSet
→ ExtensionSet?
-
Markdown syntax extension set
finalinherited
-
fitContent
→ bool
-
Whether to allow the widget to fit the child content.
finalinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
imageBuilder
→ MarkdownImageBuilder?
-
Called to build an image widget.
finalinherited
-
imageDirectory
→ String?
-
The base directory holding images referenced by Img tags with local or network file paths.
finalinherited
-
inlineSyntaxes
→ List<InlineSyntax>?
-
Collection of custom inline syntax types to be used parsing the Markdown data.
finalinherited
-
key
→ Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
listItemCrossAxisAlignment
→ MarkdownListItemCrossAxisAlignment
-
Controls the cross axis alignment for the bullet and list item content
in lists.
finalinherited
-
maxLines
→ int?
-
final
-
onSelectionChanged
→ MarkdownOnSelectionChangedCallback?
-
Called when the user changes selection when
selectable is set to true.
finalinherited
-
onTapLink
→ MarkdownTapLinkCallback?
-
Called when the user taps a link.
finalinherited
-
onTapText
→ VoidCallback?
-
Default tap handler used when
selectable is set to true
finalinherited
-
paddingBuilders
→ Map<String, MarkdownPaddingBuilder>
-
Add padding for different tags (use only for block elements and img)
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectable
→ bool
-
If true, the text is selectable.
finalinherited
-
sizedImageBuilder
→ MarkdownSizedImageBuilder?
-
Called to build an image widget with size information.
finalinherited
-
softLineBreak
→ bool
-
The soft line break is used to identify the spaces at the end of aline of
text and the leading spaces in the immediately following the line of text.
finalinherited
-
styleSheet
→ MarkdownStyleSheet?
-
The styles to use when displaying the Markdown.
finalinherited
-
styleSheetTheme
→ MarkdownStyleSheetBaseTheme?
-
Setting to specify base theme for MarkdownStyleSheet
finalinherited
-
syntaxHighlighter
→ SyntaxHighlighter?
-
The syntax highlighter used to color text in
pre elements.
finalinherited