imageBuilder property

  1. @Deprecated('Use sizedImageBuilder instead')
MarkdownImageBuilder? imageBuilder
finalinherited

Called to build an image widget.

This builder allows for custom rendering of images within the Markdown content. It provides the image Uri, title, and alt text.

Deprecated: Use sizedImageBuilder instead, which offers more comprehensive image information.

Only one of imageBuilder or sizedImageBuilder may be specified.

Implementation

@Deprecated('Use sizedImageBuilder instead')
final MarkdownImageBuilder? imageBuilder;