sizedImageBuilder property
MarkdownSizedImageBuilder?
sizedImageBuilder
finalinherited
Called to build an image widget with size information.
This builder allows for custom rendering of images within the Markdown content
when size information is available. It provides a MarkdownImageConfig
containing the Uri, title, alt, width, and height of the image.
If both imageBuilder and sizedImageBuilder are null, a default image builder
will be used.
when size information is available. It provides a MarkdownImageConfig
containing the Uri, title, alt, width, and height of the image.
If both imageBuilder and sizedImageBuilder are null, a default
image builder will be used.
Only one of imageBuilder or sizedImageBuilder may be specified.
Implementation
final MarkdownSizedImageBuilder? sizedImageBuilder;